ReplCommand

Enum ReplCommand 

pub enum ReplCommand {
    Banner,
    Tui,
    Edit,
    Toml,
    Run,
    Delete,
    List,
    History,
    Help,
    Keys,
    Theme,
    Quit,
}
REPL mode lets you type or paste a Rust expression to be evaluated.

Enter the expression to be evaluated.

Expressions between matching braces, brackets, parens or quotes may span multiple lines.

Expressions starting with “// “, “/// “, or “[Cc]omment “ will be ignored as comments.

If valid, the expression will be converted into a Rust program, and built and run using Cargo.

Dependencies will be inferred from imports if possible using a Cargo search, but the overhead of doing so can be avoided by placing them in Cargo.toml format at the top of the expression in a comment block of the form

/*[toml]
[dependencies]
...
*/

From here they will be extracted to a dedicated Cargo.toml file.

In this case the whole expression must be enclosed in curly braces to include the TOML in the expression.

At any stage before exiting the REPL, or at least as long as your TMPDIR is not cleared, you can go back and edit your expression or its generated Cargo.toml file and copy or save them from the editor or directly from their temporary disk locations.

The tab key will show command selections and complete partial matching selections.

Variants



Banner

Show the REPL banner



Tui

Promote the Rust expression to the TUI REPL, which can handle any script. This is a one-way process, but the original expression will be saved in history.



Edit

Edit the Rust expression in the configured or default editor. Edit+run is an alternative to prompt-line evaluation or TUI for longer snippets and programs.



Toml

Edit the generated Cargo.toml



Run

Attempt to build and run the Rust expression



Delete

Delete all temporary files for the current evaluation (see list command)



List

List temporary files for this the current evaluation



History

Edit history



Help

Show help information



Keys

Show key bindings



Theme

Show theme and terminal attributes (change via thag -C and rerun)



Quit

Exit the REPL