pub struct ReplPrompt(pub &'static str);Expand description
A struct to implement the Prompt trait.
Tuple Fields
0: &'static strTrait Implementations
Sourceimpl Prompt for ReplPrompt
impl Prompt for ReplPrompt
Sourcefn render_prompt_left(&self) -> Cow<'_, str>
fn render_prompt_left(&self) -> Cow<'_, str>
Provide content of the left full prompt
Sourcefn render_prompt_right(&self) -> Cow<'_, str>
fn render_prompt_right(&self) -> Cow<'_, str>
Provide content of the right full prompt
Sourcefn render_prompt_indicator(&self, _edit_mode: PromptEditMode) -> Cow<'_, str>
fn render_prompt_indicator(&self, _edit_mode: PromptEditMode) -> Cow<'_, str>
Render the prompt indicator (Last part of the prompt that changes based on the editor mode)
Sourcefn render_prompt_multiline_indicator(&self) -> Cow<'_, str>
fn render_prompt_multiline_indicator(&self) -> Cow<'_, str>
Indicator to show before explicit new lines
Sourcefn render_prompt_history_search_indicator(
&self,
history_search: PromptHistorySearch,
) -> Cow<'_, str>
fn render_prompt_history_search_indicator( &self, history_search: PromptHistorySearch, ) -> Cow<'_, str>
Render the prompt indicator for
Ctrl-R history searchSourcefn get_prompt_color(&self) -> Color
fn get_prompt_color(&self) -> Color
Get the default prompt color
Sourcefn get_prompt_multiline_color(&self) -> Color
fn get_prompt_multiline_color(&self) -> Color
Get the default multiline prompt color
Sourcefn get_indicator_color(&self) -> Color
fn get_indicator_color(&self) -> Color
Get the default indicator color
Sourcefn get_prompt_right_color(&self) -> Color
fn get_prompt_right_color(&self) -> Color
Get the default right prompt color
Sourcefn right_prompt_on_last_line(&self) -> bool
fn right_prompt_on_last_line(&self) -> bool
Whether to render right prompt on the last line